@@ -84,7 +84,7 @@ class RegionEstimator(object):
         # Make all non integer values Null in measurement fields
         #   Make sure value columns at the end of column list
         cols = actuals.columns.tolist()
-        cols = cols['timestamp'] + cols['sensor_id'] + cols.difference(['timestamp','sensor_id'])
+        cols = cols[['timestamp']] + cols[['sensor_id']] + cols.difference(['timestamp','sensor_id'])
         actuals = actuals[cols]
         #   Coerce all non numeric values in value columns to be numeric or None
         actuals[2:] = pd.to_numeric(actuals[2:], errors='coerce')
